=========
GPUEngine
=========

This object provides fine-grained control over the behavior of the
GPU engine when calling `LazyFrame.collect()` with an `engine`
argument.

.. currentmodule:: polars.lazyframe.engine_config

.. autosummary::
   :toctree: api/

    GPUEngine
